@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI Utilities
 
-our $VERSION = '0.0402';
+our $VERSION = '0.0403';
 
 use strict;
 use warnings;
@@ -157,6 +157,18 @@ sub dump {
     }
 }
 
+
+sub midi_format {
+    my (@notes) = @_;
+    my @formatted;
+    for my $note (@notes) {
+        $note =~ s/#/s/;
+        $note =~ s/b/f/;
+        push @formatted, $note;
+    }
+    return @formatted;
+}
+
 1;
 
 __END__
@@ -171,7 +183,7 @@ MIDI::Util - MIDI Utilities
 
 =head1 VERSION
 
-version 0.0402
+version 0.0403
 
 =head1 SYNOPSIS
 
@@ -185,6 +197,8 @@ version 0.0402
 
   my $dump = MIDI::Util::dump('volume');
 
+  my @notes = midi_format('C','C#','Db','D'); # C, Cs, Df, D
+
 =head1 DESCRIPTION
 
 C<MIDI::Util> comprises handy MIDI utilities.
@@ -272,6 +286,13 @@ L<MIDI::Simple>, and L<MIDI::Event> internal lists:
   Text_events
   Nontext_meta_events
 
+=head2 midi_format
+
+  @formatted = MIDI::Util::midi_format(@notes);
+
+Change sharp C<#> and flat C<b>, in the list of named notes, to the
+L<MIDI::Simple> C<s> and C<f> respectively.
+
 =head1 SEE ALSO
 
 L<MIDI>
@@ -290,7 +311,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Gene Boggs.
+This software is copyright (c) 2020 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
